<?php

if ( !defined( 'ABSPATH' ) ) {
	exit; // Exit if accessed directly
}

/**
 * Manages product includes folder
 *
 * Here all plugin includes folder is defined and managed.
 *
 * @version		1.0.0
 * @package		ecommerce-product-catalog/includes
 * @author 		impleCode
 */
class ic_epc_blocks {

	public $singular_name, $plural_name;

	function __construct() {
		if ( function_exists( 'register_block_type' ) ) {
			add_action( 'init', array( $this, 'register' ) );
			add_action( 'enqueue_block_editor_assets', array( $this, 'enqueue' ) );
			add_filter( 'block_categories', array( $this, 'block_category' ), 10, 2 );
		}
	}

	function enqueue() {
		$names				 = get_catalog_names();
		$this->singular_name = $names[ 'singular' ];
		$this->plural_name	 = $names[ 'plural' ];

		wp_enqueue_script( 'ic-epc-show-products' );
		wp_localize_script( 'ic-epc-show-products', 'ic_epc_blocks', array(
			'strings'				 => array(
				'show_products'		 => sprintf( __( 'Show %s', 'ecommerce-product-catalog' ), $this->singular_name ),
				'show'				 => __( 'Show', 'ecommerce-product-catalog' ),
				'select_products'	 => sprintf( __( 'Select %s', 'ecommerce-product-catalog' ), $this->singular_name ),
				'select_categories'	 => __( 'Select Categories', 'ecommerce-product-catalog' ),
				'select_limit'		 => sprintf( __( 'Set %s Limit', 'ecommerce-product-catalog' ), $this->singular_name ),
				'select_orderby'	 => __( 'Order by', 'ecommerce-product-catalog' ),
				'select_order'		 => __( 'Order Type', 'ecommerce-product-catalog' ),
				'select_template'	 => __( 'Listing Template', 'ecommerce-product-catalog' ),
				'select_perrow'		 => __( 'Items Per Row', 'ecommerce-product-catalog' ),
				'choose_products'	 => sprintf( __( 'Choose %s to Display', 'ecommerce-product-catalog' ), $this->singular_name ),
				'by_category'		 => __( 'By Category', 'ecommerce-product-catalog' ),
				'by_product'		 => sprintf( __( 'By %s', 'ecommerce-product-catalog' ), $this->singular_name ),
				'sort_limit'		 => __( 'Sort & Limit', 'ecommerce-product-catalog' ),
			),
			'category_options'		 => $this->categories(),
			'product_options'		 => $this->products(),
			'orderby_options'		 => $this->orderby(),
			'order_options'			 => $this->order(),
			'template_options'		 => $this->template(),
			'per_row_def'			 => 3,
			'products_limit_def'	 => 10,
			'archive_template_def'	 => get_product_listing_template()
		)
		);
		do_action( 'ic_enqueue_block_scripts', $this->singular_name, $this->plural_name );
	}

	function register() {
		wp_register_script( 'ic-epc-show-products', AL_PLUGIN_BASE_PATH . 'includes/blocks/js/show-products-block.js' . ic_filemtime( AL_BASE_PATH . '/includes/blocks/js/show-products-block.js' ), array( 'wp-blocks', 'wp-element', 'wp-i18n', 'ic_chosen' ), null, true );

		register_block_type( 'ic-epc/show-products', array(
			'attributes'		 => array(
				'category'			 => array(
					'type'		 => 'array',
					'default'	 => array(),
					'items'		 => array( 'type' => 'integer' )
				),
				'product'			 => array(
					'type'		 => 'array',
					'default'	 => array(),
					'items'		 => array( 'type' => 'integer' )
				),
				'products_limit'	 => array(
					'type'		 => 'string',
					'default'	 => 10
				),
				'orderby'			 => array(
					'type'		 => 'string',
					'default'	 => ''
				),
				'order'				 => array(
					'type'		 => 'string',
					'default'	 => ''
				),
				'archive_template'	 => array(
					'type'		 => 'string',
					'default'	 => get_product_listing_template()
				),
				'per_row'			 => array(
					'type'		 => 'string',
					'default'	 => 3
				)
			),
			'render_callback'	 => array( $this, 'render_products' ),
		) );
		do_action( 'ic_register_blocks' );
	}

	function render_products( $atts = null ) {
		if ( isset( $atts[ 'product' ] ) && is_array( $atts[ 'product' ] ) ) {
			$atts[ 'product' ] = implode( ',', $atts[ 'product' ] );
		}
		if ( isset( $atts[ 'category' ] ) && is_array( $atts[ 'category' ] ) ) {
			$atts[ 'category' ] = implode( ',', $atts[ 'category' ] );
		}
		if ( !empty( $atts[ 'orderby' ] ) ) {
			$atts[ 'orderby' ] = translate_product_order( $atts[ 'orderby' ] );
		}
		return show_products_outside_loop( $atts );
	}

	function block_category( $categories, $post ) {
		$categories[] = array(
			'slug'	 => 'ic-epc-block-cat',
			'title'	 => __( 'Catalog', 'ecommerce-product-catalog' ),
			'icon'	 => null,
		);

		return $categories;
	}

	function categories() {
		$args				 = array();
		$args[ 'taxonomy' ]	 = apply_filters( 'show_categories_taxonomy', 'al_product-cat', $args );
		$args[ 'parent' ]	 = '0';
		$cats				 = get_terms( $args );
		$return				 = array();
		$return[]			 = array( 'value' => 0, 'label' => __( 'All', 'ecommerce-product-catalog' ) );
		foreach ( $cats as $cat ) {
			$return[] = array( 'value' => $cat->term_id, 'label' => $cat->name );
		}
		return $return;
	}

	function products() {
		$all_products	 = get_all_catalog_products();
		$return			 = array();
		$return[]		 = array( 'value' => 0, 'label' => __( 'All', 'ecommerce-product-catalog' ) );
		foreach ( $all_products as $product ) {
			$return[] = array( 'value' => $product->ID, 'label' => $product->post_title );
		}
		return $return;
	}

	function orderby() {
		$sorting_options = get_product_sort_options();
		$return			 = array();
		foreach ( $sorting_options as $name => $label ) {
			$return[] = array( 'value' => $name, 'label' => $label );
		}
		return $return;
	}

	function order() {
		return array(
			array( 'value' => 'ASC', 'label' => __( 'ASC', 'ecommerce-product-catalog' ) ),
			array( 'value' => 'DESC', 'label' => __( 'DESC', 'ecommerce-product-catalog' ) )
		);
	}

	function template() {
		$templates	 = ic_get_available_templates();
		$return		 = array();
		foreach ( $templates as $name => $label ) {
			$return[] = array( 'value' => $name, 'label' => $label );
		}
		return $return;
	}

}

$ic_epc_blocks = new ic_epc_blocks;


